.. _cli:

CLI
===

The command line interface (CLI) is one of three modes of usage, next to *abgleich*'s :ref:`GUI <gui>` and :ref:`API <api>`.

.. click:: abgleich.cli:cli
  :prog: abgleich
  :show-nested:
